;;; CoAX process description
;;; Author: Jeff Dalton <J.Dalton@ed.ac.uk>
;;; Created: June 2000
;;; Updated: Sun Jul  1 18:33:19 2001 by Jeff Dalton
;;; Copyright: (c) 2000, AIAI, University of Edinburgh


(define-process ("conduct coalition_mission")
  (nodes
    (1 ("monitor C2 process"))
    (2 ("task refinement"))
    (3 ("initial planning"))
    (4 ("ongoing operations"))
    (5 ("intelligence updates")))
  (orderings
    (3 4)))


(define-product ("Joint Operational Estimate"))
(define-product ("Air Estimate"))
(define-product ("JTFC's Campaign Plan"))
(define-product ("JFACC's Air Operations Plan"))


;;; Monitor C2 Process

(define-action ("monitor C2 process")
  (properties
    ("initial-status" "N/A")))


;;; Task Refinement

(define-action ("task refinement")
  (properties
    ("initial-status" "N/A")))


;;; Initial Planning

(define-action ("initial planning")
  (nodes
    (1 ("develop joint operational estimate"))
    (2 ("develop air estimate"))
    (3 ("produce JTFC's campaign plan"))
    (4 ("produce JFACC's air operations plan")))
  (orderings
    ((1 2) (3 4))))


(define-action ("develop joint operational estimate")
  (nodes
    (1 ("transmit mission to JFACC [message S1M1a]"))
    (2 ("transmit JTFC's mission directive to JFACC [message S1M2a]"))
    (3 ("consider joint operational COAs"))
    (4 ("transmit JTFC's intent to JFACC [message S1M3a]"))
    (5 ("request JFACC draft estimate [message S1M4a]")))
  (orderings
    (1 2 3 4 5))
  (effects
    (at start
      (status ("Joint Operational Estimate")) = :draft)
    (at finish
      (status ("Joint Operational Estimate")) = :complete)))

(define-action ("transmit mission to JFACC [message S1M1a]"))
(define-action ("transmit JTFC's mission directive to JFACC [message S1M2a]"))
(define-action ("consider joint operational COAs"))
(define-action ("transmit JTFC's intent to JFACC [message S1M3a]"))
(define-action ("request JFACC draft estimate [message S1M4a]"))


(define-action ("develop air estimate")
  (nodes
    (1 ("confirm receipt of S1M1a [message S1M1b]"))
    (2 ("confirm receipt of S1M2a [message S1M2b]"))
    (3 ("confirm receipt of S1M3a [message S1M3b]"))
    (4 ("request intelligence report [message I1a]"))
    (5 ("assemble information and intelligence"))
    (6 ("consider Air COAs"))
    (7 ("provide JFACC draft estimate [message S1M4b]")))
  ; (orderings
  ;   (1 2 3 4 5 6 7))
  (effects
    (at start
      (status ("Air Estimate")) = :draft)
    (at finish
      (status ("Air Estimate")) = :complete)))

(define-action ("confirm receipt of S1M1a [message S1M1b]"))
(define-action ("confirm receipt of S1M2a [message S1M2b]"))
(define-action ("confirm receipt of S1M3a [message S1M3b]"))
(define-action ("request intelligence report [message I1a]"))
(define-action ("assemble information and intelligence"))
(define-action ("consider Air COAs"))
(define-action ("provide JFACC draft estimate [message S1M4b]"))


(define-action ("produce JTFC's campaign plan")
  (nodes
    (1 ("request information on availability of assets [message S2M1a]"))
    (2 ("request for apportionment recommendation [message S2M2a]"))
    (3 ("consider possible campaign COAs"))
    (4 ("produce joint campaign plan")))
  (orderings
    (1 2 3 4))
  (effects
    (at start
      (status ("JTFC's Campaign Plan")) = :draft)
    (at finish
      (status ("JTFC's Campaign Plan")) = :complete)))


(define-action ("request information on availability of assets [message S2M1a]"))
(define-action ("request for apportionment recommendation [message S2M2a]"))
(define-action ("consider possible campaign COAs"))
(define-action ("produce joint campaign plan"))


(define-action ("produce JFACC's air operations plan")
  (nodes
    (1 ("provide information on availability of assets [message S2M1b]"))
    (2 ("provide apportionment recommendation [message S2M2b]"))
    (3 ("consider possible operations COAs"))
    (4 ("produce air operations plan")))
  (orderings
    ; was (1 2 3 4)
    ((1 2 3) 4))
  (effects
    (at start
      (status ("JFACC's Air Operations Plan")) = :draft)
    (at finish
      (status ("JFACC's Air Operations Plan")) = :complete)))


(define-action ("provide information on availability of assets [message S2M1b]"))
(define-action ("provide apportionment recommendation [message S2M2b]"))
(define-action ("consider possible operations COAs"))
(define-action ("produce air operations plan"))


;;; Ongoing operations

(define-action ("ongoing operations"))


;;; Intelligence updates

(define-action ("intelligence updates")
  (nodes
    (1 ("continuous intelligence updates"))
    (2 ("wait for rfi"))
    (3 ("gather intelligence"))
    (4 ("collate intelligence"))
    (5 ("fuse intelligence"))
    (6 ("provide intelligence [message I1b]")))
  (orderings
    (2 3 4 5 6)
    (6 2)))

(define-action ("continuous intelligence updates"))
(define-action ("wait for rfi")
  (properties
    ("loop-entry" "true")))
(define-action ("gather intelligence"))
(define-action ("collate intelligence"))
(define-action ("fuse intelligence"))
(define-action ("provide intelligence [message I1b]"))


;;; End
