/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed Jul 18 18:29:08 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.grid;

// Grid imports
import com.globalinfotek.coabsgrid.AgentRegistrationHelper;
import com.globalinfotek.coabsgrid.MessageListener;
import com.globalinfotek.coabsgrid.Message;
import com.globalinfotek.coabsgrid.BasicMessage;
import com.globalinfotek.coabsgrid.AgentRep;
import com.globalinfotek.coabsgrid.entry.AgentRepUIDescriptor;

import java.io.IOException;
import java.io.StringReader;

// Imports for using JDOM
// import java.io.IOException;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jdom.output.XMLOutputter;

import ix.icore.Issue;
import ix.icore.BasicIssue;

import ix.iface.util.XML;

import ix.util.lisp.*;		// only for Issue -> XML
import ix.util.*;

/**
 * A class that encapsulates the Grid knowledge needed for
 * sending and receiving our Grid messages.
 */
public class GridCommunicationStrategy 
implements IPC.CommunicationStrategy, MessageListener {

    public String ipcName = "ipcName unknown";

    public IPC.MessageListener ipcListener = null;

    public AgentRegistrationHelper reg;


    public GridCommunicationStrategy() {
    }


    /**
     * Sends an Issue or Report to a named Grid agent by converting
     * it to XML and calling the <code>sendText</code> method.
     */
    public void sendObject(Object destination, Object contents) {
	String toName = (String)destination;
	sendText(toName, XML.objectToXML(contents));
    }

    /**
     * Sends a string to a named Grid agent.
     */
    public void sendText(String toName, String contents) {

	// Look up the agent we're sending to.
	AgentRep toRep = reg.getDirectory().getAgentRepByName(toName);
	if (toRep == null) {
	    Debug.noteln("Cannot find grid agent", toName);
	    return;
	}

	// Construct a message.  We could leave the first 3 new BasicMessage
	// parameters null like this:
	//
	// BasicMessage message = new BasicMessage(null, null, null, contents);
	//
	// But instead we will fill some in.  The constructor is
	//
	// BasicMessage(java.lang.String receiver,
	//              ServiceRep sender,
	//              java.lang.String acl,
	//              java.lang.String rawText)
	//
	BasicMessage message = 
	    new BasicMessage(toName,
			     reg.getGridAgent().getAgentRep(),
			     null,
			     contents);
	// Would reg.getAgentRep() also work as the 2nd arg? /\/

	// Now send
	try { toRep.addMessage(message); }
	catch (Exception e) {
	    Debug.noteException(e);
	}

    }

    /**
     * Register as an agent and set up for receiving messages.
     */
    public void setupServer(Object destination, 
			    IPC.MessageListener listener) {
	ipcName = (String)destination;   // our name for registering as agent
	ipcListener = listener;
	try {
	    reg = new AgentRegistrationHelper(ipcName);
	    reg.addMessageListener(this);
	    reg.registerAgent();
	}
	catch (IOException e) {
	    Debug.noteException(e);
	}
    }

    /**
     * Called when a new Grid message has been added to our message queue.
     */
    public synchronized void messageAdded(Message message) {
	// Note that we might get some registration messages
	// that we can ignore.
	Debug.noteln("Grid message:", message);
	String text = message.getRawText();
	if (text != null && text.startsWith("<")) {
	    // Looks like XML ...
	    Debug.noteln("Received XML via Grid", text);
	    try {
		Object contents = XML.objectFromXML(text);
		Debug.noteln("Object from XML", contents);
		ipcListener
		    .messageReceived(new IPC.BasicInputMessage(contents));
	    }
	    catch (Throwable e) {
		Debug.noteln("Problem parsing", e);
	    }
	}
	else {
	    Debug.noteln("Ignoring message", message);
	}
	reg.removeMessage(message);
    }


}
