/*
*  Copyright:    Copyright (c) 2001 Global InfoTek, Inc.
*  Author:       Martha L. Kahn
*  Date:         July, 1999
*  Company:      Global InfoTek, Inc.
*  Description:  A very simple agent that registers, gets
*                notified when it receives Messages, and
*                has a GUI.
*
********************************************************************************
********************************************************************************
* Revision History
*/
package ix.grid;

import com.globalinfotek.coabsgrid.AgentRegistrationHelper;
import com.globalinfotek.coabsgrid.MessageListener;
import com.globalinfotek.coabsgrid.Message;
import com.globalinfotek.coabsgrid.BasicMessage;
import com.globalinfotek.coabsgrid.AgentRep;
import com.globalinfotek.coabsgrid.entry.AgentRepUIDescriptor;

import java.io.IOException;
import java.io.StringReader;

// Imports for using JDOM
// import java.io.IOException;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jdom.output.XMLOutputter;

import ix.util.*;

/**
A very simple agent that registers, is notified when it gets a message,
and has a user interface.
*  Send bug reports to coabsgrid-bugs@globalinfotek.com
*  @author Martha L. Kahn, Global InfoTek, Inc.
**/
public class Test implements MessageListener 
{
      
      private AgentRegistrationHelper reg;

      String name;
      static String otherName;

      public Test(String name) throws IOException 
      {
	 reg = new AgentRegistrationHelper(name);
	 reg.addMessageListener(this);
	 // reg.addAdvertisedCapability(new AgentRepUIDescriptor("What's up?"));
	 reg.registerAgent();
	 startSendLoop();
      }

      public synchronized void messageAdded(Message msg) {
	 System.out.println("******* RECEIVED MESSAGE *******\n" + msg);
	 parseXML(msg.getRawText());
	 reg.removeMessage(msg);
      }

      protected String SAXDriverClass = "org.apache.xerces.parsers.SAXParser";

      void parseXML(String text)
      {
	 StringReader sr = new StringReader(text);
	 try
	 {
	    SAXBuilder builder = new SAXBuilder(SAXDriverClass);
	    Document doc = builder.build(sr);
	    	// Create an outputter with 3 space indent and newlines=true

	    XMLOutputter outputter = new XMLOutputter("   ", true);
	    outputter.setTrimText(true);
	    outputter.output(doc, System.out);
	    System.out.flush();
	 }
	 catch (Exception e)
	 {
	    Debug.noteException(e);
	 }
      }

      void startSendLoop()
      {
	 Debug.noteln("Starting send loop");
	 new Thread() 
	    {
		  public void run()
		  {
		     sendLoop();
		  }
	     }.start();
      }
      

      /** Main program. Instantiates an agent. **/
      public static void main(String[] args) throws IOException 
      {
	 otherName = args[1];
	 if (args.length > 0) new Test(args[0]);
	 else new Test("Test");
      }

      void sendLoop() 
      {
	 while(true)
	 {
	    String text = Util.askLine("Message: ");
	    AgentRep rep = reg.getDirectory().getAgentRepByName(otherName);
	    if (rep == null)
	       continue;
	    BasicMessage message = new BasicMessage(null, rep, null, text);
	    try { rep.addMessage(message); }
	    catch (Exception e) 
	    {
	       e.printStackTrace();
	    }
	 }
      }
            
}

