/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Tue Jul 17 21:42:38 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.icore;

import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;

import ix.icore.process.StatusValues;

import ix.util.lisp.*;

/**
 * A minimal Issue class.
 */

public class BasicIssue implements Issue, StatusValues, Serializable {

    protected Object verb;
    protected LList parameters;
    protected int status = STATUS_BLANK;
    protected int priority = PRIORITY_MEDIUM;
    protected Map properties = new HashMap(5);

    public BasicIssue(String text) {
	this(Lisp.elementsFromString(text));
    }

    public BasicIssue(LList pattern) {
	this.verb = pattern.car();
	this.parameters = pattern.cdr();
    }

    public BasicIssue(Issue i) {
	this(Lisp.cons(i.getVerb(), (LList)i.getParameters()));
	setPriority(i.getPriority());
	properties.putAll((Map)i.getProperties());
    }

    public Object getVerb() { return verb; }

    public Object getParameters() { return parameters; }

    public int getStatus() { return status; }

    public void setStatus(int status) { this.status = status; }

    public int getPriority() { return priority; }

    public void setPriority(int priority) { this.priority = priority; }

    public Map getProperties() { return properties; }

    public void setProperties(Map properties) {
	this.properties = properties;
    }

    public String toString() {
	return "issue[" + Lisp.elementsToString(Lisp.cons(verb, parameters))
	    + "]";
    }

}
