/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Fri Jul 20 01:55:05 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.ideel;

import javax.swing.*;

import java.util.*;

import ix.iface.domain.DomainParser;

import ix.icore.domain.*;
import ix.icore.domain.event.*;
import ix.icore.*;
import ix.util.*;


/** 
 * The generic I-DEEL class and application main program 
 */

public class BasicIdeel extends IXAgent {

    Domain domain = new Domain();

    IdeelFrame frame;

    IdeelController controller = new IdeelController();

    IssueViewingTable issueViewer;

    public Object getAgentIPCName() { return "IDEEL"; }

    public BasicIdeel() {
	super();
    }

    /**
     * Main program.
     */
    public static void main(String[] argv) {

	Util.printGreeting("Basic I-DEEL");

	new BasicIdeel().mainStartup(argv);

    }

    /**
     * Command-line argument processing for arguments used by all
     * versions of I-DEEL.
     */
    protected void processCommandLineArguments() {
	super.processCommandLineArguments();
    }

    /**
     * Completes basic I-DEEL setup and initialization.
     */
    public void startup() {
	frame = new IdeelFrame("I-DEEL");
	frame.setOwner(this);
	issueViewer = frame.issueViewer;
	issueViewer.setIssueManager(controller);
	controller.setDomain(domain);
	controller.addControllerListener(issueViewer);
	readDomain(domain);
	addIdeelIssueHandlers();
    }

    /**
     * Read in any default domain description.
     */
    protected void readDomain(Domain domain) {
    }


    /**
     * Called to restore the initial state.
     */
    public void reset() {
	// /\/: Things should register for reset instead of being known here.
	controller.reset();	// should contoller tell issueViewer? /\/
	issueViewer.reset();
	frame.validate();
    }


    /**
     * Handles new issues from external sources.
     */
    public void handleNewIssue(Issue issue) {
        controller.addIssue(issue);
    }

    /**
     * Handles new reports from external  sources.
     */
    public void handleNewReport(Report report) {
	controller.newReport(report);
    }


    /**
     * Install any generic issue handlers for issues it can
     * handle automatically.
     */ 
    void addIdeelIssueHandlers() {
    }

}

// Issues:
// * Should the class name be BasicIdeel or just Ideel?  So long as the
//   class I_DEEL exists, BasicIdeel will be less confusing / error-prone.

