/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Thu Oct 18 12:32:05 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.ideel;

import java.util.*;

import ix.iface.domain.DomainParser;
import ix.icore.domain.Domain;
import ix.icore.Issue;
import ix.icore.BasicIssueHandler;
import ix.icore.Report;

import ix.util.*;
import ix.util.lisp.*;


/** 
 * The CoAX I-DEEL class and application main program.
 */

public class I_DEEL extends BasicIdeel {

    public I_DEEL() {
	super();
    }

    /**
     * Main program.
     */
    public static void main(String[] argv) {

	Util.printGreeting("I-DEEL");

	new I_DEEL().mainStartup(argv);

    }

    /**
     * Read in default domain description.
     */
    protected void readDomain(Domain domain) {
	super.readDomain(domain);		// read any generic domain
	try {
	    DomainParser.makeParser("binni-ideel.xml").readDomain(domain);
	}
	catch (Exception e) {
	    Debug.noteException(e);
	}
    }


    /**
     * Install I-DEEL's own issue handlers for issues it can
     * handle automatically.
     */ 
    void addIdeelIssueHandlers() {

	super.addIdeelIssueHandlers();

	controller.addIssueHandler
	    ("report",
	     // Want to be able to say "report to <sender id>" /\/
	     new IdeelIssueHandler("report to JTFC/ILEED") {
		public void handleIssue(Issue i) {
		    String text = 
			Lisp.elementsToString((LList)i.getParameters());
		    Report report = new Report(text);
		    report.getProperties().put("sender-id", getAgentIPCName());
		    IPC.sendObject(i.getProperties().get("sender-id"), report);
		    i.setStatus(STATUS_COMPLETE);
		}
	    });

	controller.addIssueHandler
	    ("deconflict_plans",
	     new IdeelIssueHandler("invoke deconfliction agent") {

		public void handleIssue(Issue i) {
		    // Here's where we'd send a request to
		    // the deconfliction agent.
		    // /\/: Probably it would not become complete
		    // until we got a report back.
		    i.setStatus(STATUS_EXECUTING);
		}

		public void addIssueOptions(IdeelIssue i) {
		    // First do what we normally do, namely add the option(s).
		    super.addIssueOptions(i);
		    // Now this gives us a chance to give the issue
		    // the required "reportRef" field.  /\/
		    String ref =  "MCA-IDEEL-1";
		    Debug.noteln("Setting reportRef of " + i
				 + " to " + Util.quote(ref));
		    i.reportRef = ref;
		}

	    });

    }

}

// Issues:
// * Will we always know where a report should go, or do we need a way
//   to ask the user?
