/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Thu Jul 12 08:02:09 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.ideel;

import javax.swing.*;

import java.awt.Container;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Dimension;

import java.awt.event.*;

import ix.ip2.*;

import ix.iview.*;
import ix.iface.util.LogoPanel;
import ix.util.*;

/**
 * The main frame of the I-DEEL user interface.
 */
class IdeelFrame extends IP2Frame implements ActionListener {

    Container contentPane;

    SimpleDomainEditor domainEditor;
    IssueViewingTable issueViewer; // s.b. just IssueViewer? /\/

    BasicIdeel ideel;

    IdeelFrame(String title) {
	super(title);
	setUp();
    }

    void setOwner (BasicIdeel ideel) {
	this.ideel = ideel;
    }

    protected void setUp() {
	issueViewer = new IssueViewingTable();

	contentPane = getContentPane();

	setSize(500, 300);
	setJMenuBar(makeMenuBar());
	// Layout manager defaults to BorderLayout.
	// contentPane.setLayout(new FlowLayout()); // probably not too clever

	// Add issue Viewer
	{
	    JPanel issuePanel = new JPanel();
	    issuePanel.add(issueViewer);
	    JScrollPane scroll = new JScrollPane(issuePanel);
	    scroll.setBorder(BorderFactory.createTitledBorder("Issues"));
	    contentPane.add(scroll, BorderLayout.CENTER);
	}

	// Add something that identifies the system and mentions AIAI
	contentPane.add(new LogoPanel("I-DEEL",
				      "I-X Dynamic Event and Execution List"),
			BorderLayout.SOUTH);

	// Find the "packed" width, then change the height.
	pack();
	{
	    Dimension size = getSize();
	    setSize(new Dimension((int)size.getWidth(), 300));
	}
	setVisible(true);
    }

    protected void ensureDomainEditor() {
	if (domainEditor == null) {
	    domainEditor = new SimpleDomainEditor(ideel.domain);
	    // domainEditor.setLocation(getX() + 100, getY() + 100);
	}
	domainEditor.setVisible(true);
    }

    public SimpleDomainEditor getDomainEditor() {
	ensureDomainEditor();
	return domainEditor;
    }


    /*
     * Menu bar
     */

    protected JMenuBar makeMenuBar() {
	JMenuBar bar = new JMenuBar();

	JMenu fileMenu = new JMenu("File");
	bar.add(fileMenu);
	fileMenu.add(makeMenuItem("Load or Edit Domain"));
	fileMenu.add(makeMenuItem("Reset"));
	fileMenu.addSeparator();
	fileMenu.add(makeMenuItem("Exit"));

	JMenu issueMenu = new JMenu("Issue");
	bar.add(issueMenu);
	issueMenu.add(makeMenuItem("New Issue"));
	issueMenu.add(makeMenuItem("New Issue Expansion"));

	bar.add(Box.createHorizontalGlue()); // let later items move right

	JMenu testMenu = new JMenu("Test");
	bar.add(testMenu);
	issueViewer.addTestMenuItems(testMenu);

	return bar;
    }

    protected JMenuItem makeMenuItem(String text) {
	JMenuItem item = new JMenuItem(text);
	item.addActionListener(this);
	return item;
    }

    /*
     * Action interpreter
     */

    public void actionPerformed(ActionEvent e) {
	String command = e.getActionCommand();
	Debug.noteln("I-DEEL action:", command);
	if (command.equals("Exit")) {
	    System.exit(0);
	}
	else if (command.equals("Reset")) {
	    ideel.reset();
	}
	else if (command.equals("Load or Edit Domain")) {
	    ensureDomainEditor();
	}
	else if (command.equals("Add example issues")) {
	    issueViewer.addExampleIssues();
	}
	else if (command.equals("Avoid elephants laki_safari_park")) {
	    issueViewer.addIssue("avoid elephants laki_safari_park");
	}
	else if (command.equals("New Issue")) {
	    issueViewer.newIssue();
	}
	else if (command.equals("New Issue Expansion")) {
	    ensureDomainEditor();
	}
	else
	    Debug.noteln("Nothing to do for", command);
    }

}

// Issues:
// * Perhaps a more abstract name, such as IdeelUserInterface, instead of
//   IdeelFrame.
