/* Author: Jeff Dalton
 * Updated: Sat Jun 30 02:54:53 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.iface.util;

import javax.swing.*;

import java.awt.Font;
import java.awt.Color;

/**
 * A panel that contains the application name and some credits.
 * It is intended to be placed at the bottom of the application's
 * main interface Frame.
 */

public class LogoPanel extends JPanel {

    public LogoPanel(String applicationName) {
	this(applicationName, "I-X Process Panel");
    }

    public LogoPanel(String applicationName, String longName) {
	super();

	ImageIcon icon = new ImageIcon("images/aiai-logo-small.gif");

	setLayout(new BoxLayout(this, BoxLayout.X_AXIS));

	// Application name in larger than default font.
	JLabel name = new JLabel(applicationName);
	Font nameFont = name.getFont();
	name.setFont(nameFont.deriveFont(nameFont.getSize2D() + (float)3.0));
	add(name);

	// I-X credits in smaller than normal font.
	{
	    Box box = Box.createVerticalBox();
	    JLabel line1 = new JLabel(longName);
	    JLabel line2 = new JLabel("Based on I-X Technology");
	    Font font = line1.getFont();
	    Font smallFont = font.deriveFont(font.getSize2D() - (float)2.0);
	    line1.setFont(smallFont);
	    line2.setFont(smallFont);
	    box.add(line1);
	    box.add(Box.createVerticalStrut(2));
	    box.add(line2);

	    add(Box.createHorizontalStrut(10));
	    add(box);
	}

	// AIAI logo over at the right edge.
	add(Box.createHorizontalGlue());
	add(new JLabel(icon));

	// It's createEmptyBorder(top, left, bottom, right)
	// setBorder(BorderFactory.createEmptyBorder(1, 4, 4, 4));

	// When making it white, need grey around the edge.
	setBorder(BorderFactory.createMatteBorder(1,4,4,4,getBackground()));
	setBackground(Color.white);

    }

}

// Issues:
// * In something like font.deriveFont(font.getSize2D() - (float)2.0),
//   the compiler says "Incompatible type for method. Explicit cast
//   needed to convert double to int." if I don't cast the 2.0 to float.
//
//   This is strange.  I call getSize2D() instead of getSize() because
//   getSize2D() returns a float - and I want a float because deriveFont
//   regards a float as a point size and an int as style.  So it's
//   not clear why it thinks I might want to convert to int.  Maybe
//   it assumes I want the deriveFont(int) method rather than the
//   deriveFont(float) one, given that a double is neither float nor int.
