/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Tue Jul 17 18:00:41 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.iface.util;

import java.text.SimpleDateFormat;
import java.util.Date;

import java.util.*;

import ix.icore.Issue;
import ix.icore.BasicIssue;
import ix.icore.Report;

import ix.util.lisp.*;
import ix.util.*;


/**
 * Class of static methods useful when reporting incoming messages etc.
 */
public class Reporting {

    static SimpleDateFormat dateFormat =
	new SimpleDateFormat("dd-MMM-yy HH:mm:ss");

    // We sometimes have to explicitly set the default timezone;
    // static { dateFormat.setTimeZone(TimeZone.getDefault()); }

    private Reporting() { }	// no instantiation

    public static String messageDescription(IPC.InputMessage message) {
	Object contents = message.getContents();
	if (contents instanceof Issue)
	    return issueDescription((Issue)contents);
	else if (contents instanceof Report)
	    return reportDescription((Report)contents);
	else
	    return "Unexpected message containing: " + message;
    }

    public static String issueDescription(Issue issue) {
	Map properties = issue.getProperties();
	String senderId = (String)properties.get("sender-id");
	String ref = (String)properties.get("ref");
	String reportBack = (String)properties.get("report-back");
	return dateString()
	    + " Issue from " + senderId
	    + (ref == null ? "" : " ref=" + ref)
	    + (reportBack == null ? "" : " report-back=" + reportBack)
	    + " priority=" + priorityDescription(issue.getPriority())
	    + ": " + Util.quote(XML.issueDescription(issue));
    }

    public static String reportDescription(Report report) {
	Map properties = report.getProperties();
	String senderId = (String)properties.get("sender-id");
	String ref = (String)properties.get("ref");
	return dateString()
	    + " Report from " + senderId
	    + (ref == null ? "" : " ref=" + ref)
	    + ": " + Util.quote(report.getText());
    }

    public static String dateString() {
	return dateFormat.format(new Date());
    }

    public static String priorityDescription(int priority) {
	return ViewColor.priorityName[priority].toLowerCase();
    }

}
