/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Thu Oct 18 12:33:52 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.ileed;

import javax.swing.*;

import java.util.*;
import java.io.*;

import ix.icore.*;
import ix.icore.domain.Domain;

import ix.ideel.IssueManager;
import ix.ideel.IdeelController;
import ix.ideel.IssueViewer;		// not used at present /\/
import ix.ideel.IssueViewingTable;

import ix.util.*;


/** 
 * The generic I-LEED class and application main program 
 */

public class BasicIleed extends IXAgent {

    Domain issueDomain = new Domain();

    IdeelController controller = new IdeelController();
 
    ProcessModel processModel = new ProcessModel();
    MessageInterpreter interpreter = new MessageInterpreter(processModel);

    ProcessViewer processViewer = new SimpleProcessViewer();

    IssueViewingTable issueViewer = new IleedIssueViewingTable();

    AutoTester autoTester = new AutoTester(this);

    public IleedFrame frame;

    public Object getAgentIPCName() { return "ILEED"; }

    public BasicIleed() {
	super();
    }

    /**
     * Main program.
     */
    public static void main(String[] argv) {

	Util.printGreeting("Basic I-LEED");

	new BasicIleed().mainStartup(argv);

    }

    /**
     * Command-line argument processing for arguments used by all
     * versions of I-LEED.
     */
    protected void processCommandLineArguments() {
	super.processCommandLineArguments();
	autoTester.processParameters();
    }

    /**
     * Completes basic I-LEED setup and initialization.
     */
    public void startup() {

	super.startup();

	addIleedIssueHandlers();

	setupProcessModel();

	// Connect controller and issue-viewer
	issueViewer.setIssueManager(controller);
	controller.addControllerListener(issueViewer);
	controller.setDomain(issueDomain);
	readIssueDomain(issueDomain);

	addIleedInitialIssues();

	// Create the outer GUI
	frame = new IleedFrame(this);

	// Start displaying the monitoring results
	processModel.sendFullStateDescription();

	// Should do this last
	frame.pack();
	frame.setVisible(true);

    }

    protected void setupProcessModel() {
	// processModel.initFromFile("coax-process.lsp");

	// Connect model and viewer.
	// processModel.setViewer(processViewer);
	// processViewer.setProcessModel(processModel);
    }


    /**
     * Read in any default issue-domain description.
     */
    protected void readIssueDomain(Domain domain) {
	Debug.noteln("BasicIleed readIssueDomain(Domain) called");
    }


    /**
     * Sets up any issues that should be in the panel at the start.
     */
    protected void addIleedInitialIssues() {
    }


    /**
     * Called to restore the initial state.
     */
    public void reset() {
	// /\/: Things should register for reset instead of being known here.
	autoTester.stopAll(); 	// do this 1st
	processModel.reset();
	interpreter.reset();
	processViewer.reset();
	processModel.sendFullStateDescription();
	controller.reset();	// or should contoller tell issueViewer? /\/
	issueViewer.reset();
	frame.validate();
    }


    /**
     * Handles new issues from external sources.
     */
    public void handleNewIssue(Issue issue) {
        controller.addIssue(issue);
    }

    /**
     * Handles new reports from external sources.
     */
    public void handleNewReport(Report report) {
	controller.newReport(report);
    }


    /**
     * Install any generic issue handlers for issues it can
     * handle automatically.
     */ 
    void addIleedIssueHandlers() {
    }

}
