/* File: ProcessStatusUpdate.java
 * Contains: The class for information sent to ProcessViewers
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: January 1998
 * Updated: Sun May 20 16:49:45 2001 by Jeff Dalton
 * Copyright: (c) 1998, 2000, 2001, AIAI, University of Edinburgh
 */

package ix.ileed;

import java.util.*;

/**
 * A ProcessStatusUpdate is sent to an implementation of the ProcessViewer
 * interface when telling it of state changes in a process. <p>
 *
 * The update always contains the current number of COAs and the
 * total number of issues for each COA, even if these numbers have
 * not changed since the previous update was sent.  The statusChanges
 * field normally contains only the changes since the last update.
 * In that case, the containsCompleteState field is false.  However,
 * if containsCompleteState is true, then statusChanges contains
 * a StatusChange object for every node that currently exists.
 *
 * @see ProcessModel
 * @see StatusChange
 * @see ProcessViewer
 */

// /\/: For now at least, we'll include Product objects directly in
// the update, rather than some status object, and we'll always include
// all of them.  Viewers should still obey containsCompleteState, though.

public class ProcessStatusUpdate {

    public int numberOfCoas;
    public Vector statusChanges; 	// Vector of StatusChanges
    public int[] issueCounts;
    public boolean containsCompleteState = false;

    public Vector products;		// the actual Products

    public ProcessStatusUpdate() {
    }

}
