/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed Oct 17 18:42:35 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.itest;

import java.util.*;
import java.awt.event.*;
import javax.swing.*;

import ix.icore.BasicIssue;
import ix.util.*;
import ix.util.lisp.*;


/**
 * The CoAX I-TEST class and application main program.
 * It defines test cases suitable for the CoAX / Binni demonstrations.
 */

public class I_TEST extends BasicItest {

    I_TEST() {
	super();
    }

    I_TEST(String frameTitle) {
	super(frameTitle);
    }

    /**
     * Main program.
     */
    public static void main(String[] argv) {

	Util.printGreeting("I-TEST");

	new I_TEST().mainStartup(argv);

    }

    /**
     * Tests
     */
    void addTests() {

	/* Any inherited tests */

  	super.addTests();

  	/* I-LEED tests */

	addReportSequenceTest
	    ("Send to ILEED MBP status reports",
	     "ILEED",
	     "MBP-ILEED-1",
	     ix.ileed.AutoTester.defaultMessageList);

	addIssueTest("ILEED", PRIORITY_HIGH,
		     "consider elephants laki_safari_park");
	addIssueTest("ILEED", PRIORITY_HIGH, "consider lions sw_region");
	addIssueTest("ILEED", PRIORITY_HIGH, "consider lions nw_region");

  	/* I-DEEL tests */

	addIssueTest("IDEEL", "avoid elephants laki_safari_park");

	addReportSequenceTest
	    ("Send to IDEEL MCA reports for no conflicts",
	     "IDEEL",
	     "MCA-IDEEL-1",
	     new String[] { "done - no conflicts" });

	addReportSequenceTest
	    ("Send to IDEEL MCA reports for no solutions",
	     "IDEEL",
	     "MCA-IDEEL-1",
	     new String[] { "done - no solutions" });

	addReportSequenceTest
	    ("Send to IDEEL MCA reports for 3 solutions",
	     "IDEEL",
	     "MCA-IDEEL-1",
	     new String[] {
		"solutions found 1",
		"solutions found 2",
		"solutions found 3",
		"done - solutions found 3"
	     });

	addReportSequenceTest
	    ("Send to IDEEL MCA reports for 10 solutions",
	     "IDEEL",
	     "MCA-IDEEL-1",
	     new String[] {
		"solutions found 1",
		"solutions found 2",
		"solutions found 3",
		"solutions found 4",
		"solutions found 5",
		"solutions found 6",
		"solutions found 7",
		"solutions found 8",
		"solutions found 9",
		"solutions found 10",
		"done - solutions found 10"
	     });

    }

}
