/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Mon May  7 18:36:13 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.util.context;

import java.util.*;

/**
 * An object that provides context-holders.
 *
 * @see Context
 */
public abstract class ContextHoldingStrategy {

    /**
     * Returns an appropriate context-holder.
     */
    public abstract ContextHolder getContextHolder();

    /**
     * Changes the context-holder that would be returned, if that
     * makes sense.  (Optional operation.)
     *
     * @throws UnsupportedOperationException if the
     *         <code>setContextHolder</code> method is not supported.
     */
    public void setContextHolder(ContextHolder h) {
	throw new UnsupportedOperationException("can't set context-holder");
    }

}
