/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed Jul 18 18:30:48 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.kaos;

// KAoS imports
import edu.uwf.kaos.coabsgrid.KAoSAgentRegistrationHelper;
import edu.uwf.kaos.coabsgrid.KAoSAgentRep;
import com.globalinfotek.coabsgrid.entry.CoABSAgentDescription;
import net.jini.core.entry.Entry;

// Grid imports
//import com.globalinfotek.coabsgrid.AgentRegistrationHelper;
import com.globalinfotek.coabsgrid.MessageListener;
import com.globalinfotek.coabsgrid.Message;
import com.globalinfotek.coabsgrid.BasicMessage;
import com.globalinfotek.coabsgrid.AgentRep;
import com.globalinfotek.coabsgrid.entry.AgentRepUIDescriptor;

import java.io.IOException;

import ix.grid.GridCommunicationStrategy;

import ix.util.*;

/**
 * A class that encapsulates the KAoS knowledge needed for
 * sending and receiving our messages.
 *
 * It uses KAoSAgentRegistrationHelper(String name)
 */
public class KaosCommunicationStrategy extends GridCommunicationStrategy {

    public KaosCommunicationStrategy() {
    }

    /**
     * Register as an agent and set up for receiving messages.
     */
    public void setupServer(Object destination, 
			    IPC.MessageListener listener) {

	ipcName = (String)destination; // our name for registering as agent
	ipcListener = listener;

        Debug.noteln("Registering KAoS agent", ipcName);
        try {
            reg = new KAoSAgentRegistrationHelper(ipcName);
            reg.addMessageListener(this);
            CoABSAgentDescription desc = new CoABSAgentDescription();
            desc.name = ipcName;
            Entry[] attributes_ = new Entry[1];
            attributes_[0] = desc;
   
            reg.addAdvertisedCapabilities(attributes_);
            // registerAgent() method is blocking.  It first registers
            // the agent with the Grid, and then it registers with the
            // DomainManager for the requested domain.
            reg.registerAgent();
        }
        catch (IOException e) {
            Debug.noteException(e);
        }
        catch (ClassNotFoundException cnfe) {
            Debug.noteException(cnfe);
        }
    }

}
