/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Tue Jun 12 16:48:33 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.util;

import java.util.*;
import java.io.*;

import junit.framework.*;

/**
 * Collection test cases.
 */
public abstract class AbstractCollectionTest extends TestCase 
implements UsefulTestObjects {

    public AbstractCollectionTest(String name) {
	super(name);
    }

    protected abstract Collection makeEmptyCollection();

    protected Collection makeCollection(Collection source) {
	Collection c = makeEmptyCollection();
	c.addAll(source);
	return c;
    }

    public void testEmptyCollection() {
	Collection c = makeEmptyCollection();
	assert("should be empty", c.isEmpty());
	// Add more assertions?
    }

    public void testOneElementCollection() {
    }

    public void testEmptySerialization() {
	serializationTest(makeEmptyCollection());
    }

    public void testOneElementSerialization() {
	// Need a nicer way of building this /\/
	serializationTest(makeCollection(ix.util.lisp.Lisp.list("Apple")));
    }

    public void testTwoElementSerizlization() {
	// Need a nicer way of building this /\/
	serializationTest(makeCollection
			  (ix.util.lisp.Lisp.list("Apple", "Pie")));
    }

    public void serializationTest(Collection c) {
	if (c instanceof Serializable) {
	    try {
		ByteArrayOutputStream byte_out = new ByteArrayOutputStream();
		ObjectOutputStream out = new ObjectOutputStream(byte_out);
		out.writeObject(c);
		out.flush();

		ByteArrayInputStream byte_in
		    = new ByteArrayInputStream(byte_out.toByteArray());
		ObjectInputStream in = new ObjectInputStream(byte_in);
		Collection new_c = (Collection)in.readObject();

		assertSame("class", c.getClass(), new_c.getClass());
		assertEquals("size", c.size(), new_c.size());
		// Remember that the collection might not be ordered.
		assert("old contains new", c.containsAll(new_c));
		assert("new contains old", new_c.containsAll(c));
	    }
	    catch(Exception e) {
		Debug.noteException(e);	// JUnit way to to this?? /\/
		fail("Exception " + e);
	    }
	}
    }

}
