/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed May  9 19:27:59 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.util;

import java.util.*;

import junit.framework.*;

/**
 * Iterator test cases.
 */
public abstract class AbstractIteratorTest extends TestCase 
implements UsefulTestObjects {

    Iterator i;

    public AbstractIteratorTest(String name) {
	super(name);
    }

    protected void tearDown() {
	i = null;
    }

    protected abstract Collection makeEmptyCollection();

    protected Collection makeCollection(Collection source) {
	Collection c = makeEmptyCollection();
	c.addAll(source);
	return c;
    }

    /**
     * Returns an Iterator that's an instance of the class to be tested.
     * Use this instead of calling the collection's <tt>iterator()</tt>
     * method.  A subclass may want this method to call the collection's
     * <tt>listIterator()</tt> method instead.
     */
    protected Iterator getIterator(Collection c) {
	return c.iterator();
    }

    public void testEmptyIterator () {
	i = getIterator(makeEmptyCollection());
	assert(!i.hasNext());
	try {
	    i.next();
	    fail("Should have thrown NoSuchElementException");
	}
	catch (NoSuchElementException e) {
	}
    }

}
