/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed May  9 19:23:36 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.util;

import java.util.*;

import junit.framework.*;

/**
 * ListIterator test cases.
 */
public abstract class AbstractListIteratorTest extends AbstractIteratorTest {

    ListIterator li;

    public AbstractListIteratorTest(String name) {
	super(name);
    }

    protected void tearDown() {
	super.tearDown();
	li = null;
    }

    protected List makeEmptyList() {
	return (List)makeEmptyCollection();
    }

    protected List makeList(Collection source) {
	return (List)makeCollection(source);
    }

    protected Iterator getIterator(Collection c) {
	return ((List)c).listIterator(); // we're testing the ListIterator.
    }

    public void testEmptyIterator() {
	super.testEmptyIterator();
	li = (ListIterator)i;
	assert(!li.hasPrevious());
	assertEquals(0, li.nextIndex());
	assertEquals(-1, li.previousIndex());
	try {
	    li.previous();
	    fail("Should have thrown NoSuchElementException");
	}
	catch (NoSuchElementException e) {
	}
    }

    public void testElementRetrieval() {
	List abc = makeList(ix.util.lisp.Lisp.list(STR_A, STR_B, STR_C));
	ListIterator abc_li = abc.listIterator();
	assert(abc_li.hasNext());
	assertSame(STR_A, abc_li.next());
	assert(abc_li.hasNext());
	assertSame(STR_B, abc_li.next());
	assert(abc_li.hasNext());
	assertSame(STR_C, abc_li.next());
	assert(!abc_li.hasNext());
    }

}
